@@ -41,6 +41,7 @@
 #include "fpointarray.h"
 #include "hyphenator.h"
 #include "insertTable.h"
+#include "pageitem_line.h"
 #include "pageitem_textframe.h"
 #include "pageselector.h"
 #include "prefscontext.h"
@@ -395,6 +396,18 @@ void CanvasMode_Normal::mouseMoveEvent(QMouseEvent *m)
 							m_objectDeltaPos.setXY(dX, dY);
 							m_doc->m_Selection->setGroupRect();
 							m_doc->m_Selection->getGroupRect(&gx, &gy, &gw, &gh);
+							// #10677 : temporary hack : we need to introduce the
+							// concept of item snapping points to handle better
+							// the various types of items
+							if (currItem->isLine())
+							{
+								QPointF startPoint = currItem->asLine()->startPoint();
+								QPointF endPoint   = currItem->asLine()->endPoint();
+								gx = qMin(startPoint.x(), endPoint.x());
+								gy = qMin(startPoint.y(), endPoint.y());
+								gw = fabs(startPoint.x() - endPoint.x());
+								gh = fabs(startPoint.y() - endPoint.y());
+							}
 							if (m_doc->SnapGuides)
 							{
 								double nx = gx + m_objectDeltaPos.x();
@@ -1198,23 +1211,21 @@ bool CanvasMode_Normal::SeleItem(QMouseEvent *m)
 			}
 			else if (currItem->Groups.count() > 0)
 			{
-				for (int ga=0; ga<m_doc->Items->count(); ++ga)
+				for (int ga=0; ga < m_doc->Items->count(); ++ga)
 				{
 					PageItem* item = m_doc->Items->at(ga);
-					if (item->Groups.count() != 0)
+					if (item->Groups.count() == 0)
+						continue;
+					if (item->Groups.top() != currItem->Groups.top())
+						continue;
+					if (item->ItemNr != currItem->ItemNr)
 					{
-						if (item->Groups.top() == currItem->Groups.top())
+						if (m_doc->m_Selection->findItem(item) == -1)
 						{
-							if (item->ItemNr != currItem->ItemNr)
-							{
-								if (m_doc->m_Selection->findItem(item) == -1)
-								{
-									m_doc->m_Selection->addItem(item, true);
-								}
-							}
-							item->isSingleSel = false;
+							m_doc->m_Selection->addItem(item, true);
 						}
 					}
+					item->isSingleSel = false;
 				}
 			}
 		}
@@ -1374,7 +1385,7 @@ void CanvasMode_Normal::importToPage()
 		else
 		{
 			FileLoader *fileLoader = new FileLoader(fileName);
-			int testResult = fileLoader->TestFile();
+			int testResult = fileLoader->testFile();
 			delete fileLoader;
 			if ((testResult != -1) && (testResult >= FORMATID_ODGIMPORT))
 			{
