@@ -22,22 +22,29 @@ for which a new license (GPL+exception) is in place.
  ***************************************************************************/
 
 #include "gradienteditor.h"
-#include "gradienteditor.moc"
-#include <qpainter.h>
-#include <qpixmap.h>
-#include <qcursor.h>
+
+#include <QApplication>
+#include <QCursor>
+#include <QEvent>
+#include <QMouseEvent>
+#include <QPaintEvent>
+#include <QPainter>
+#include <QPixmap>
+#include <QPolygon>
+#include <QToolTip>
+
+
 #include "scpainter.h"
 #include "fpoint.h"
-extern QPixmap loadIcon(QString nam);
+#include "util_icon.h"
 
-GradientPreview::GradientPreview(QWidget *pa) : QLabel(pa)
+GradientPreview::GradientPreview(QWidget *pa) : QFrame(pa)
 {
 	setFrameShape( QFrame::Panel );
 	setFrameShadow( QFrame::Sunken );
 	setLineWidth( 2 );
-	setEraseColor(QColor(255,255,255));
-	setMinimumSize(QSize(200, 80));
-	setMaximumSize(QSize(3000, 80));
+	setMinimumSize(QSize(200, 70));
+	setMaximumSize(QSize(3000, 70));
 	setMouseTracking(true);
 	Mpressed = false;
 	outside = true;
@@ -51,7 +58,7 @@ GradientPreview::GradientPreview(QWidget *pa) : QLabel(pa)
 	color = QColor(0,0,0);
 	fill_gradient.addStop( color, 1.0, 0.5, 1.0 );
 
-	QPtrVector<VColorStop> cstops = fill_gradient.colorStops();
+	QList<VColorStop*> cstops = fill_gradient.colorStops();
 	StopM.clear();
 	ActStop = 0;
 	for (uint a = 0; a < fill_gradient.Stops(); ++a)
@@ -63,16 +70,17 @@ GradientPreview::GradientPreview(QWidget *pa) : QLabel(pa)
 
 void GradientPreview::paintEvent(QPaintEvent *e)
 {
-	QPtrVector<VColorStop> cstops = fill_gradient.colorStops();
+	QList<VColorStop*> cstops = fill_gradient.colorStops();
 	StopM.clear();
 	for (uint a = 0; a < fill_gradient.Stops(); ++a)
 	{
 		int center = qRound(cstops.at(a)->rampPoint * (width()-20))+10;
 		StopM.append(center);
 	}
-	QPixmap pixm(width()-20, 37);
+	QImage pixm(width()-20, 37, QImage::Format_ARGB32);
 	ScPainter *p = new ScPainter(&pixm, width()-20, 37);
-	p->setPen(black);
+	p->clear(Qt::white);
+	p->setPen(Qt::black);
 	p->setLineWidth(1);
 	p->setFillMode(2);
 	p->fill_gradient = fill_gradient;
@@ -82,21 +90,21 @@ void GradientPreview::paintEvent(QPaintEvent *e)
 	delete p;
 	QPainter pw;
 	pw.begin(this);
-	pw.drawPixmap(10, 5, pixm);
+	pw.drawImage(10, 5, pixm);
 	for (uint a = 0; a < fill_gradient.Stops(); ++a)
 	{
 		int center = qRound(cstops.at(a)->rampPoint * (width()-20))+10;
-		pw.setPen(QPen(black, 1, SolidLine, FlatCap, MiterJoin));
-		if (StopM[QMAX(ActStop,0)] == center)
-			pw.setBrush(red);
+		pw.setPen(QPen(Qt::black, 1, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin));
+		if (StopM[qMax(ActStop,0)] == center)
+			pw.setBrush(Qt::red);
 		else
-			pw.setBrush(blue);
-		QPointArray cr;
+			pw.setBrush(Qt::blue);
+		QPolygon cr;
 		cr.setPoints(3, qRound(center), 43, qRound(center-4), 56, qRound(center+4), 56);
 		pw.drawPolygon(cr);
 	}
 	pw.end();
-	QLabel::paintEvent(e);
+	QFrame::paintEvent(e);
 }
 
 void GradientPreview::mousePressEvent(QMouseEvent *m)
@@ -104,7 +112,7 @@ void GradientPreview::mousePressEvent(QMouseEvent *m)
 	QRect fpo;
 	Mpressed = true;
 	ActStop = -1;
-	QPtrVector<VColorStop> cstops = fill_gradient.colorStops();
+	QList<VColorStop*> cstops = fill_gradient.colorStops();
 	for (int yg = 0; yg < static_cast<int>(StopM.count()); ++yg)
 	{
 		fpo = QRect(static_cast<int>(StopM[yg])-4, 43, 8, 13);
@@ -124,22 +132,25 @@ void GradientPreview::mousePressEvent(QMouseEvent *m)
 void GradientPreview::mouseReleaseEvent(QMouseEvent *m)
 {
 	QRect fpo;
-	if ((Mpressed) && (ActStop != 0) && (ActStop != static_cast<int>(StopM.count()-1)) && (ActStop != -1) && (outside || m->y() > 60))
+	if ((Mpressed) && (ActStop > 0) && (ActStop != static_cast<int>(StopM.count()-1)) && (outside || m->y() > 60))
 	{
 		onlyselect = false;
 		fill_gradient.removeStop(ActStop);
 		ActStop = 0;
 		repaint();
-		QPtrVector<VColorStop> cstops = fill_gradient.colorStops();
+		QList<VColorStop*> cstops = fill_gradient.colorStops();
 		emit selectedColor(cstops.at(ActStop)->name, cstops.at(ActStop)->shade);
 		emit currTrans(cstops.at(ActStop)->opacity);
 		emit currStep(cstops.at(ActStop)->rampPoint);
 	}
-	if ((m->y() < 60) && (m->y() > 43) && (m->x() > 0) && (m->x() < width()) && (ActStop == -1))
+	if ((m->y() < height()) && (m->y() > 43) && (m->x() > 0) && (m->x() < width()) && (ActStop == -1))
 	{
-		QPtrVector<VColorStop> cstops = fill_gradient.colorStops();
-		double newStop = static_cast<double>((m->x() - 10)) / (static_cast<double>(width())-20);
-		fill_gradient.addStop(cstops.at(0)->color, newStop, 0.5, 1.0, cstops.at(0)->name, cstops.at(0)->shade);
+		QList<VColorStop*> cstops = fill_gradient.colorStops();
+		double  newStop = static_cast<double>((m->x() - 10)) / (static_cast<double>(width())-20);
+		QColor  stopColor = (cstops.count() > 0) ? cstops.at(0)->color : QColor(255, 255, 255);
+		QString stopName  = (cstops.count() > 0) ? cstops.at(0)->name  : QString("White");
+		int     stopShade = (cstops.count() > 0) ? cstops.at(0)->shade : 100;
+		fill_gradient.addStop(stopColor, newStop, 0.5, 1.0, stopName, stopShade);
 		repaint();
 		onlyselect = false;
 		cstops = fill_gradient.colorStops();
@@ -165,23 +176,23 @@ void GradientPreview::mouseReleaseEvent(QMouseEvent *m)
 void GradientPreview::mouseMoveEvent(QMouseEvent *m)
 {
 	QRect fpo;
-	qApp->setOverrideCursor(QCursor(ArrowCursor), true);
-	if ((!Mpressed) && (m->y() < 60) && (m->y() > 43) && (m->x() > 9) && (m->x() < width()-9))
+	qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
+	if ((!Mpressed) && (m->y() < height()) && (m->y() > 43) && (m->x() > 9) && (m->x() < width()-9))
 	{
-		qApp->setOverrideCursor(QCursor(loadIcon("AddPoint.png"), 1, 1), true);
+		qApp->changeOverrideCursor(QCursor(loadIcon("AddPoint.png"), 1, 1));
 		for (int yg = 0; yg < static_cast<int>(StopM.count()); ++yg)
 		{
 			fpo = QRect(static_cast<int>(StopM[yg])-4, 43, 8, 13);
 			if (fpo.contains(m->pos()))
 			{
-				qApp->setOverrideCursor(QCursor(SizeHorCursor), true);
+				qApp->changeOverrideCursor(QCursor(Qt::SizeHorCursor));
 				return;
 			}
 		}
 	}
-	if ((Mpressed) && (m->y() < 60) && (m->y() > 43) && (m->x() > 9) && (m->x() < width()-9) && (ActStop != -1))
+	if ((Mpressed) && (m->y() < height()) && (m->y() > 43) && (m->x() > 9) && (m->x() < width()-9) && (ActStop != -1))
 	{
-		qApp->setOverrideCursor(QCursor(SizeHorCursor), true);
+		qApp->changeOverrideCursor(QCursor(Qt::SizeHorCursor));
 		double newStop = static_cast<double>((m->x() - 10)) / (static_cast<double>(width())-20);
 		if (ActStop > 1)
 		{
@@ -194,23 +205,23 @@ void GradientPreview::mouseMoveEvent(QMouseEvent *m)
 				return;
 		}
 		StopM[ActStop] = m->x();
-		QPtrVector<VColorStop> cstops = fill_gradient.colorStops();
+		QList<VColorStop*> cstops = fill_gradient.colorStops();
 		cstops.at(ActStop)->rampPoint = newStop;
 		emit currStep(cstops.at(ActStop)->rampPoint);
-		cstops.sort();
+		qSort(cstops.begin(), cstops.end());
 		onlyselect = false;
 		repaint();
 	}
-	if ((Mpressed) && (outside || m->y() > 60) && (ActStop != 0) && (ActStop != static_cast<int>(StopM.count()-1)) && (ActStop != -1))
-		qApp->setOverrideCursor(QCursor(loadIcon("DelPoint.png"), 1, 1), true);
+	if ((Mpressed) && (outside || m->y() > 60) && (ActStop > 0) && (ActStop != static_cast<int>(StopM.count()-1)))
+		qApp->changeOverrideCursor(QCursor(loadIcon("DelPoint.png"), 1, 1));
 }
 
 void GradientPreview::leaveEvent(QEvent*)
 {
-	if ((Mpressed) && (ActStop != 0) && (ActStop != static_cast<int>(StopM.count()-1)) && (ActStop != -1))
-		qApp->setOverrideCursor(QCursor(loadIcon("DelPoint.png"), 1, 1), true);
+	if ((Mpressed) && (ActStop > 0) && (ActStop != static_cast<int>(StopM.count()-1)))
+		qApp->changeOverrideCursor(QCursor(loadIcon("DelPoint.png"), 1, 1));
 	else
-		qApp->setOverrideCursor(QCursor(ArrowCursor), true);
+		qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
 	outside = true;
 }
 
@@ -223,17 +234,20 @@ void GradientPreview::updateDisplay()
 {
 	repaint();
 	ActStop = 0;
-	QPtrVector<VColorStop> cstops = fill_gradient.colorStops();
-	emit selectedColor(cstops.at(ActStop)->name, cstops.at(ActStop)->shade);
-	emit currTrans(cstops.at(ActStop)->opacity);
-	emit currStep(cstops.at(ActStop)->rampPoint);
+	if (!fill_gradient.colorStops().isEmpty())
+	{
+		QList<VColorStop*> cstops = fill_gradient.colorStops();
+		emit selectedColor(cstops.at(ActStop)->name, cstops.at(ActStop)->shade);
+		emit currTrans(cstops.at(ActStop)->opacity);
+		emit currStep(cstops.at(ActStop)->rampPoint);
+	}
 }
 
 void GradientPreview::setActColor(QColor c, QString n, int s)
 {
 	if (ActStop == -1)
 		return;
-	QPtrVector<VColorStop> cstops = fill_gradient.colorStops();
+	QList<VColorStop*> cstops = fill_gradient.colorStops();
 	cstops.at(ActStop)->color = c;
 	cstops.at(ActStop)->name = n;
 	cstops.at(ActStop)->shade = s;
@@ -244,7 +258,7 @@ void GradientPreview::setActTrans(double t)
 {
 	if (ActStop == -1)
 		return;
-	QPtrVector<VColorStop> cstops = fill_gradient.colorStops();
+	QList<VColorStop*> cstops = fill_gradient.colorStops();
 	cstops.at(ActStop)->opacity = t;
 	repaint();
 }
@@ -253,32 +267,36 @@ void GradientPreview::setActStep(double t)
 {
 	if (ActStop == -1)
 		return;
-	QPtrVector<VColorStop> cstops = fill_gradient.colorStops();
+	QList<VColorStop*> cstops = fill_gradient.colorStops();
 	cstops.at(ActStop)->rampPoint = t;
 	repaint();
 }
 
-GradientEditor::GradientEditor(QWidget *pa) : QLabel(pa)
+GradientEditor::GradientEditor(QWidget *pa) : QFrame(pa)
 {
-	Form1Layout = new QVBoxLayout( this, 0, 0, "Form1Layout");
+	setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Maximum));
+	setFrameShape( QFrame::Panel );
+	setLineWidth( 1 );
+	QGridLayout *gridLayout = new QGridLayout(this);
+	gridLayout->setSpacing(2);
+	gridLayout->setMargin(2);
+
 	Preview = new GradientPreview(this);
-	Form1Layout->addWidget(Preview);
-	Layout1 = new QHBoxLayout(0,0,0,"Layout1");
-	Layout1->setSpacing( 4 );
-	Layout1->setMargin( 0 );
-	Position = new QSpinBox( this, "shspin" );
-	Position->setMinValue(0);
-	Position->setMaxValue(100);
-	Position->setLineStep(1);
+	gridLayout->addWidget(Preview, 0, 0, 1, 2);
+
+	Position = new QSpinBox( this );
+	Position->setMinimum(0);
+	Position->setMaximum(100);
+	Position->setSingleStep(1);
 	Position->setValue(0);
-	Desc = new QLabel( this, "Desc" );
+	Desc = new QLabel( this );
 	languageChange();
-	Layout1->addWidget( Desc );
-	Layout1->addWidget(Position);
-	Form1Layout->addLayout(Layout1);
+
+	gridLayout->addWidget(Desc, 1, 0, 1, 1);
+	gridLayout->addWidget(Position, 1, 1, 1, 1);
+
 	connect(Position, SIGNAL(valueChanged(int)), this, SLOT(changePos(int)));
 	connect(Preview, SIGNAL(currStep(double)), this, SLOT(setPos(double)));
-	resize(minimumSizeHint());
 }
 
 void GradientEditor::setPos(double p)
@@ -294,10 +312,29 @@ void GradientEditor::changePos(int v)
 	emit gradientChanged();
 }
 
+void GradientEditor::changeEvent(QEvent *e)
+{
+	if (e->type() == QEvent::LanguageChange)
+	{
+		languageChange();
+	}
+	else
+		QWidget::changeEvent(e);
+}
+
 void GradientEditor::languageChange()
 {
-	QToolTip::remove(Preview);
-	QToolTip::add(Preview, QRect(10,43, Preview->width()-20, 13), tr( "Add, change or remove color stops here" ) );
 	Desc->setText( tr( "Position:" ) );
 	Position->setSuffix( tr(" %") );
 }
+
+bool GradientEditor::event(QEvent * event)
+{
+	if (event->type() == QEvent::ToolTip) 
+	{
+		QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
+		QToolTip::showText(helpEvent->globalPos(), tr( "Add, change or remove color stops here" ), Preview, QRect(10,43, Preview->width()-20, 13));
+	}
+	return QWidget::event(event);
+}
+
