@@ -21,58 +21,21 @@ for which a new license (GPL+exception) is in place.
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
  ***************************************************************************/
 
 #ifndef GTDIALOGS_H
 #define GTDIALOGS_H
 
-#include <qcheckbox.h>
-#include <qcombobox.h>
-#include <qdialog.h>
-#include <qdir.h>
-#include <qfiledialog.h>
-#include <qframe.h>
-#include <qinputdialog.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qobject.h>
-#include <qpushbutton.h>
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qtextcodec.h>
-#include <qtoolbutton.h>
-#include <qtooltip.h>
+#include <QDialog>
 
 #include "scribusapi.h"
 
 class PrefsContext;
+class QComboBox;
+class QCheckBox;
+class gtFileDialog;
 
-class SCRIBUS_API gtFileDialog : public QFileDialog
-{
-	Q_OBJECT
-private:
-	QDir dir;
-	QFrame* importerFrame;
-	QFrame* encodingFrame;
-	QHBoxLayout* importerLayout;
-	QHBoxLayout* encodingLayout;
-	QToolButton* HomeB;
-	void createWidgets(const QStringList& importers);
-public:
-	gtFileDialog(const QString& filters, const QStringList& importers, const QString& wdir);
-	~gtFileDialog();
-	QCheckBox* textOnlyCheckBox;
-	QComboBox* importerCombo;
-	QComboBox* encodingCombo;
-protected:
-	void loadSettings(void);
-	void saveSettings(void);
-public slots:
-	virtual void accept(void);
-private slots:
-	void slotHome();
-};
 
 class SCRIBUS_API gtImporterDialog : public QDialog
 {
