@@ -21,7 +21,7 @@ for which a new license (GPL+exception) is in place.
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
  ***************************************************************************/
 
 #ifndef STYLEREADER_H
@@ -29,15 +29,13 @@ for which a new license (GPL+exception) is in place.
 
 #include "scconfig.h"
 
-#ifdef HAVE_XML
-
 #ifdef HAVE_XML26
  #include <libxml/SAX2.h>
 #else
  #include <libxml/SAX.h>
 #endif
-#include <qmap.h>
-#include <qxml.h>
+#include <QMap>
+#include <QXmlAttributes>
 #include <gtstyle.h>
 #include <gtwriter.h>
 
@@ -86,6 +84,4 @@ public:
 	QString getFont(const QString& key);
 };
 
-#endif // HAVE_XML
-
 #endif
