@@ -147,9 +147,6 @@ bool PctPlug::import(QString fNameIn, const TransactionSettings& trSettings, int
 		m_Doc->m_pageSize = "Custom";
 	}
 	Elements.clear();
-	FPoint minSize = m_Doc->minCanvasCoordinate;
-	FPoint maxSize = m_Doc->maxCanvasCoordinate;
-	FPoint cOrigin = m_Doc->view()->canvasOrigin();
 	m_Doc->view()->Deselect();
 	m_Doc->setLoading(true);
 	m_Doc->DoDrawing = false;
