@@ -4,32 +4,34 @@ to the COPYING file provided with the program. Following this notice may exist
 a copyright and/or license notice that predates the release of Scribus 1.3.2
 for which a new license (GPL+exception) is in place.
 */
+#include <vector>
+#include <iostream>
+
 #include "objprinter.h"
 #include "cmdutil.h"
 #include "prefsmanager.h"
 
 #include <structmember.h>
-#include <qfileinfo.h>
-#include <qdir.h>
-#include <vector>
+#include <QFileInfo>
+#include <QDir>
+
 #include "pslib.h"
-#include "gsutil.h"
-#include "printerutil.h"
-#include "util.h"
+#include "scpaths.h"
+#include "scribuscore.h"
+#include "util_file.h"
+#include "util_ghostscript.h"
+#include "util_printer.h"
 
 #ifdef HAVE_CUPS
 #include <cups/cups.h>
 #endif
-#ifdef HAVE_CMS
-extern bool SCRIBUS_API CMSuse;
-#endif
 // these functions are located at utils.cpp
 bool SCRIBUS_API loadText(QString nam, QString *Buffer);
 void SCRIBUS_API ReOrderText(ScribusDoc *doc, ScribusView *view);
 // end of utils.cpp
 
 #if defined(_WIN32)
-#include "scwinprint.h"
+#include "scprintengine_gdi.h"
 #endif
 
 typedef struct
@@ -62,10 +64,10 @@ static void Printer_dealloc(Printer* self)
 	self->ob_type->tp_free((PyObject *)self);
 }
 
-static PyObject * Printer_new(PyTypeObject *type, PyObject */*args*/, PyObject */*kwds*/)
+static PyObject * Printer_new(PyTypeObject *type, PyObject * /*args*/, PyObject * /*kwds*/)
 {
 // do not create new object if there is no opened document
-	if (!ScMW->HaveDoc) {
+	if (!ScCore->primaryMainWindow()->HaveDoc) {
 		PyErr_SetString(PyExc_SystemError, "Need to open document first");
 		return NULL;
 	}
@@ -127,7 +129,7 @@ static PyObject * Printer_new(PyTypeObject *type, PyObject */*args*/, PyObject *
 	return (PyObject *) self;
 }
 
-static int Printer_init(Printer *self, PyObject */*args*/, PyObject */*kwds*/)
+static int Printer_init(Printer *self, PyObject * /*args*/, PyObject * /*kwds*/)
 {
 // pool system for installed printers
 // most code is stolen and little adopted from druck.cpp
@@ -137,12 +139,12 @@ static int Printer_init(Printer *self, PyObject */*args*/, PyObject */*kwds*/)
 		self->allPrinters = allPrinters;
 	}
 	QStringList printers = PrinterUtil::getPrinterNames();
-	for (uint i = 0; i < printers.count(); ++i)
+	for (int i = 0; i < printers.count(); ++i)
 	{
 		QString prn = printers[i];
 		if (prn.isEmpty())
 			continue;
-		PyObject *tmppr = PyString_FromString(prn);
+		PyObject *tmppr = PyString_FromString(prn.toLocal8Bit().constData());
 		if (tmppr){
 			PyList_Append(self->allPrinters, tmppr);
 			Py_DECREF(tmppr);
@@ -159,13 +161,13 @@ static int Printer_init(Printer *self, PyObject */*args*/, PyObject */*kwds*/)
 		self->printer = printer;
 	}
 // set defaul name of file to print into
-	QString tf = ScMW->doc->PDF_Options.Datei;
+	QString tf = ScCore->primaryMainWindow()->doc->PDF_Options.fileName;
 	if (tf.isEmpty()) {
-		QFileInfo fi = QFileInfo(ScMW->doc->DocName);
-		tf = fi.dirPath()+"/"+fi.baseName()+".pdf";
+		QFileInfo fi = QFileInfo(ScCore->primaryMainWindow()->doc->DocName);
+		tf = fi.path()+"/"+fi.baseName()+".pdf";
 	}
 	PyObject *file = NULL;
-	file = PyString_FromString(tf.ascii());
+	file = PyString_FromString(tf.toAscii());
 	if (file){
 		Py_DECREF(self->file);
 		self->file = file;
@@ -184,10 +186,10 @@ static int Printer_init(Printer *self, PyObject */*args*/, PyObject */*kwds*/)
 // set to print all pages
 	PyObject *pages = NULL;
 	int num = 0;
-	if (ScMW->HaveDoc)
+	if (ScCore->primaryMainWindow()->HaveDoc)
 		// which one should I use ???
-		// new = ScMW->view->Pages.count()
-		num = ScMW->doc->Pages->count();
+		// new = ScCore->primaryMainWindow()->view->Pages.count()
+		num = ScCore->primaryMainWindow()->doc->Pages->count();
 	pages = PyList_New(num);
 	if (pages){
 		Py_DECREF(self->pages);
@@ -236,25 +238,25 @@ static PyMemberDef Printer_members[] = {
 
 /* Here begins Getter & Setter functions */
 
-static PyObject *Printer_getallPrinters(Printer *self, void */*closure*/)
+static PyObject *Printer_getallPrinters(Printer *self, void * /*closure*/)
 {
 	Py_INCREF(self->allPrinters);
 	return self->allPrinters;
 }
 
-static int Printer_setallPrinters(Printer */*self*/, PyObject */*value*/, void */*closure*/)
+static int Printer_setallPrinters(Printer * /*self*/, PyObject * /*value*/, void * /*closure*/)
 {
 	PyErr_SetString(PyExc_ValueError, "'allPrinters' attribute is READ-ONLY");
 	return -1;
 }
 
-static PyObject *Printer_getprinter(Printer *self, void */*closure*/)
+static PyObject *Printer_getprinter(Printer *self, void * /*closure*/)
 {
 	Py_INCREF(self->printer);
 	return self->printer;
 }
 
-static int Printer_setprinter(Printer *self, PyObject *value, void */*closure*/)
+static int Printer_setprinter(Printer *self, PyObject *value, void * /*closure*/)
 {
 	if (value == NULL) {
 		PyErr_SetString(PyExc_TypeError, "Cannot delete 'printer' attribute.");
@@ -279,13 +281,13 @@ static int Printer_setprinter(Printer *self, PyObject *value, void */*closure*/)
 	return 0;
 }
 
-static PyObject *Printer_getfile(Printer *self, void */*closure*/)
+static PyObject *Printer_getfile(Printer *self, void * /*closure*/)
 {
 	Py_INCREF(self->file);
 	return self->file;
 }
 
-static int Printer_setfile(Printer *self, PyObject *value, void */*closure*/)
+static int Printer_setfile(Printer *self, PyObject *value, void * /*closure*/)
 {
 	if (value == NULL) {
 		PyErr_SetString(PyExc_TypeError, "Cannot delete 'file' attribute.");
@@ -301,13 +303,13 @@ static int Printer_setfile(Printer *self, PyObject *value, void */*closure*/)
 	return 0;
 }
 
-static PyObject *Printer_getcmd(Printer *self, void */*closure*/)
+static PyObject *Printer_getcmd(Printer *self, void * /*closure*/)
 {
 	Py_INCREF(self->cmd);
 	return self->cmd;
 }
 
-static int Printer_setcmd(Printer *self, PyObject *value, void */*closure*/)
+static int Printer_setcmd(Printer *self, PyObject *value, void * /*closure*/)
 {
 	if (value == NULL) {
 		PyErr_SetString(PyExc_TypeError, "Cannot delete 'cmd' attribute.");
@@ -323,13 +325,13 @@ static int Printer_setcmd(Printer *self, PyObject *value, void */*closure*/)
 	return 0;
 }
 
-static PyObject *Printer_getpages(Printer *self, void */*closure*/)
+static PyObject *Printer_getpages(Printer *self, void * /*closure*/)
 {
 	Py_INCREF(self->pages);
 	return self->pages;
 }
 
-static int Printer_setpages(Printer *self, PyObject *value, void */*closure*/)
+static int Printer_setpages(Printer *self, PyObject *value, void * /*closure*/)
 {
 	if (value == NULL) {
 		PyErr_SetString(PyExc_TypeError, "Cannot delete 'pages' attribute.");
@@ -346,7 +348,7 @@ static int Printer_setpages(Printer *self, PyObject *value, void */*closure*/)
 			PyErr_SetString(PyExc_TypeError, "'pages' attribute must be list containing only integers.");
 			return -1;
 		}
-		if (PyInt_AsLong(tmp) > static_cast<int>(ScMW->doc->Pages->count()) || PyInt_AsLong(tmp) < 1) {
+		if (PyInt_AsLong(tmp) > static_cast<int>(ScCore->primaryMainWindow()->doc->Pages->count()) || PyInt_AsLong(tmp) < 1) {
 			PyErr_SetString(PyExc_ValueError, "'pages' value out of range.");
 			return -1;
 		}
@@ -357,13 +359,13 @@ static int Printer_setpages(Printer *self, PyObject *value, void */*closure*/)
 	return 0;
 }
 
-static PyObject *Printer_getseparation(Printer *self, void */*closure*/)
+static PyObject *Printer_getseparation(Printer *self, void * /*closure*/)
 {
 	Py_INCREF(self->separation);
 	return self->separation;
 }
 
-static int Printer_setseparation(Printer *self, PyObject *value, void */*closure*/)
+static int Printer_setseparation(Printer *self, PyObject *value, void * /*closure*/)
 {
 	if (value == NULL) {
 		PyErr_SetString(PyExc_TypeError, "Cannot delete 'separation' attribute.");
@@ -393,102 +395,98 @@ static PyGetSetDef Printer_getseters [] = {
 // Here we actually print
 static PyObject *Printer_print(Printer *self)
 {
-	if (!ScMW->HaveDoc) {
+	if (!ScCore->primaryMainWindow()->HaveDoc) {
 		PyErr_SetString(PyExc_SystemError, "Need to open documetnt first");
 		return NULL;
 	}
 // copied from void ScribusMainWindow::slotFilePrint() in file scribus.cpp
 	QString fna, prn, cmd, scmd, cc, data, SepName;
 	QString printcomm;
-	int Nr, PSLevel;
-	bool fil, sep, color, PSfile, mirrorH, mirrorV, useICC, DoGCR;
+	bool fil, PSfile;
 	PSfile = false;
 
-//    ReOrderText(ScMW->doc, ScMW->view);
+//    ReOrderText(ScCore->primaryMainWindow()->doc, ScCore->primaryMainWindow()->view);
 	prn = QString(PyString_AsString(self->printer));
 	fna = QString(PyString_AsString(self->file));
 	fil = (QString(PyString_AsString(self->printer)) == QString("File")) ? true : false;
 	std::vector<int> pageNs;
+	PrintOptions options;
 	for (int i = 0; i < PyList_Size(self->pages); ++i) {
-		pageNs.push_back((int)PyInt_AsLong(PyList_GetItem(self->pages, i)));
+		options.pageNumbers.push_back((int)PyInt_AsLong(PyList_GetItem(self->pages, i)));
 	}
-	Nr = (self->copies < 1) ? 1 : self->copies;
+	int Nr = (self->copies < 1) ? 1 : self->copies;
 	SepName = QString(PyString_AsString(self->separation));
-	sep =(SepName == QString("No")) ?  false : true;
-//	 if (SepName == QString("All"))
-//		 SepName = tr(SepName);
-	color = self->color;
-	mirrorH = self->mph;
-	mirrorV = self->mpv;
-	useICC = self->useICC;
-	DoGCR = self->ucr;
-	int psl = self->pslevel;
-	if (psl < 1)
-		psl = 1;
-	else if (psl > 3)
-		psl = 3;
-	PSLevel = psl;
+	options.printer   = prn;
+	options.prnEngine = (PrintEngine) self->pslevel;
+	options.toFile    = fil;
+	options.separationName = SepName;
+	options.outputSeparations = (SepName == QString("No")) ?  false : true;
+	options.useColor = self->color;
+	options.mirrorH  = self->mph;
+	options.mirrorV  = self->mpv;
+	options.useICC   = self->useICC;
+	options.doGCR    = self->ucr;
+	options.cropMarks  = false;
+	options.bleedMarks = false;
+	options.registrationMarks = false;
+	options.colorMarks = false;
+	options.markOffset = 0.0;
+	options.bleeds.Top    = 0.0;
+	options.bleeds.Left   = 0.0;
+	options.bleeds.Right  = 0.0;
+	options.bleeds.Bottom = 0.0;
+	if (!PrinterUtil::checkPrintEngineSupport(options.printer, options.prnEngine, options.toFile))
+		options.prnEngine = PrinterUtil::getDefaultPrintEngine(options.printer, options.toFile);
 	printcomm = QString(PyString_AsString(self->cmd));
-	QMap<QString,int> ReallyUsed;
+	QMap<QString, QMap<uint, FPointArray> > ReallyUsed;
 	ReallyUsed.clear();
-	ScMW->doc->getUsedFonts(&ReallyUsed);
+	ScCore->primaryMainWindow()->doc->getUsedFonts(ReallyUsed);
 	PrefsManager *prefsManager=PrefsManager::instance();
 
 #if defined(_WIN32)
-	if (!fil)
+	if (!options.toFile)
 	{
-		PrintOptions options;
-		options.printer  = prn;
-		options.filename = fna;
-		options.toFile   = fil;
-		options.pageNumbers = pageNs;
-		options.copies   = Nr;
-		options.outputSeparations = sep;
-		options.separationName    = SepName;
-		options.allSeparations    = false;
-		options.useColor = color;
-		options.mirrorH  = mirrorH;
-		options.mirrorV  = mirrorV;
-		options.useICC   = useICC;
-		options.doClip   = false;
-		options.doGCR    = DoGCR;
-		options.PSLevel  = psl;
-		options.setDevParam = false;
-		options.useAltPrintCommand = false;
-
 		QByteArray devMode;
 		bool printDone = false;
-		if ( PrinterUtil::getDefaultSettings(prn, devMode) )
+		if ( PrinterUtil::getDefaultSettings(prn, options.devMode) )
 		{
-			ScWinPrint winPrint;
-			printDone = winPrint.print( ScMW->doc, options, devMode, false );
+			ScPrintEngine_GDI winPrint;
+			printDone = winPrint.print( *ScCore->primaryMainWindow()->doc, options );
 		}
 		if (!printDone)
 			PyErr_SetString(PyExc_SystemError, "Printing failed");
-		Py_INCREF(Py_None);
-		return Py_None;
+		Py_RETURN_NONE;
 	}
 #endif
 
-	PSLib *dd = new PSLib(true, prefsManager->appPrefs.AvailFonts, ReallyUsed, ScMW->doc->PageColors, false, true);
+	PSLib *dd = new PSLib(options, true, prefsManager->appPrefs.AvailFonts, ReallyUsed, ScCore->primaryMainWindow()->doc->PageColors, false, true);
 	if (dd != NULL)
 	{
 		if (!fil)
-			fna = ScMW->PrefsPfad + "/tmp.ps";
+			fna = QDir::toNativeSeparators(ScPaths::getTempFileDir()+"/tmp.ps");
 		PSfile = dd->PS_set_file(fna);
-		fna = QDir::convertSeparators(fna);
+		fna = QDir::toNativeSeparators(fna);
 		if (PSfile)
 		{
-			QStringList spots;
-			dd->CreatePS(ScMW->doc, /*ScMW->view, */pageNs, sep, SepName, spots, color, mirrorH, mirrorV, useICC, DoGCR, false, false);
-			if (PSLevel != 3)
+			options.setDevParam = false;
+			options.doClip = false;
+			dd->CreatePS(ScCore->primaryMainWindow()->doc, options);
+			if (options.prnEngine == PostScript1 || options.prnEngine == PostScript2)
 			{
-				QString tmp;
-				QStringList opts;
-				opts.append( QString("-dDEVICEWIDTHPOINTS=%1").arg(tmp.setNum(ScMW->doc->pageWidth)) );
-				opts.append( QString("-dDEVICEHEIGHTPOINTS=%1").arg(tmp.setNum(ScMW->doc->pageHeight)) );
-				convertPS2PS(fna, fna+".tmp", opts, PSLevel);
-				moveFile( fna + ".tmp", fna );
+				if (ScCore->haveGS())
+				{
+					QString tmp;
+					QStringList opts;
+					opts.append( QString("-dDEVICEWIDTHPOINTS=%1").arg(tmp.setNum(ScCore->primaryMainWindow()->doc->pageWidth)) );
+					opts.append( QString("-dDEVICEHEIGHTPOINTS=%1").arg(tmp.setNum(ScCore->primaryMainWindow()->doc->pageHeight)) );
+					convertPS2PS(fna, fna+".tmp", opts, options.prnEngine);
+					moveFile( fna + ".tmp", fna );
+				}
+				else
+				{
+					PyErr_SetString(PyExc_SystemError, "Printing failed : GhostScript is needed to print to PostScript Level 1 or Level 2");
+					Py_RETURN_NONE;
+				}
 			}
 
 			if (!fil)
@@ -506,8 +504,8 @@ static PyObject *Printer_print(Printer *self)
 #endif
 					cmd += " "+fna;
 				}
-				system(cmd);
-				unlink(fna);
+				system(cmd.toLocal8Bit().constData());
+				unlink(fna.toLocal8Bit().constData());
 			}
 		}
 		else {
@@ -517,8 +515,9 @@ static PyObject *Printer_print(Printer *self)
 		}
 		delete dd;
 	}
-	Py_INCREF(Py_None);
-	return Py_None;
+//	Py_INCREF(Py_None);
+//	return Py_None;
+	Py_RETURN_NONE;
 }
 
 static PyMethodDef Printer_methods[] = {
