@@ -4,33 +4,33 @@ to the COPYING file provided with the program. Following this notice may exist
 a copyright and/or license notice that predates the release of Scribus 1.3.2
 for which a new license (GPL+exception) is in place.
 */
+#include <QDir>
 #include "runscriptdialog.h"
-#include "runscriptdialog.moc"
-#include "qdir.h"
 #include "prefsmanager.h"
 
 QString RunScriptDialog::m_lastScriptDir;
 
 RunScriptDialog::RunScriptDialog(QWidget* parent = 0, bool extEnable = false) :
-	QFileDialog(parent, "runScriptDialog", true)
+	QDialog(parent)
 {
-	this->extEnable = extEnable;
-	PrefsManager *prefsManager = PrefsManager::instance();
-	QString prefScriptDir = prefsManager->appPrefs.ScriptDir;
-	if (!m_lastScriptDir.isEmpty() && QDir(m_lastScriptDir).exists())
-		setDir(m_lastScriptDir);
-	else if (!prefScriptDir.isEmpty() && QDir(prefScriptDir).exists())
-		setDir(prefsManager->appPrefs.ScriptDir);
-	else
-		setDir(QDir::currentDirPath());
-	setFilters( tr("Python Scripts (*.py);; All Files (*)"));
+	setupUi(this);
 
-	if (extEnable)
-	{
-		extChk = new QCheckBox( tr("Run as Extension Script", "run script dialog"), this);
-		extChk->setChecked(false);
-		addWidgets(0, extChk, 0);
-	}
+	m_extEnable = extEnable;
+	PrefsManager *prefsManager = PrefsManager::instance();
+	QString       scriptDir    = prefsManager->appPrefs.ScriptDir;
+	if (!m_lastScriptDir.isEmpty() && QDir(m_lastScriptDir).exists())
+		fileWidget->setDirectory(m_lastScriptDir);
+	else if (!scriptDir.isEmpty() && QDir(scriptDir).exists())
+		fileWidget->setDirectory(scriptDir);
+	else
+		fileWidget->setDirectory(QDir::current());
+	fileWidget->setFilter( tr("Python Scripts (*.py *.PY);; All Files (*)"));
+
+	if (!extEnable)
+		extChk->setVisible(false);
+
+	connect(fileWidget, SIGNAL(accepted()), this, SLOT(accept()));
+	connect(fileWidget, SIGNAL(rejected()), this, SLOT(reject()));
 }
 
 RunScriptDialog::~RunScriptDialog()
@@ -39,14 +39,19 @@ RunScriptDialog::~RunScriptDialog()
 
 bool RunScriptDialog::extensionRequested()
 {
-	if (extEnable)
+	if (m_extEnable)
 		return extChk->isChecked();
 	else
 		return false;
 }
 
+QString RunScriptDialog::selectedFile()
+{
+	return fileWidget->selectedFile();
+}
+
 void RunScriptDialog:: accept()
 {
-	m_lastScriptDir = dirPath();
-	QFileDialog::accept();
+	m_lastScriptDir = fileWidget->directory().path();
+	QDialog::accept();
 }
