@@ -15,16 +15,18 @@ This program is free software - see LICENSE file in the distribution
 or documentation
 */
 
-#include <qcheckbox.h>
-#include <qcursor.h>
-#include <qdir.h>
-#include <qfile.h>
-#include <qmessagebox.h>
-#include <qprogressdialog.h>
-#include <qtextcodec.h>
+#include <QCheckBox>
+#include <QCursor>
+#include <QDir>
+#include <QFile>
+#include <QMessageBox>
+#include <QProgressBar>
+#include <QTextCodec>
+//Added by qt3to4:
+#include <QPixmap>
 
 #include "shortwords.h"
-#include "shortwords.moc"
+//#include "shortwords.moc"
 #include "version.h"
 #include "vlnadialog.h"
 #include "configuration.h"
@@ -33,7 +35,7 @@ or documentation
 #include "swprefsgui.h"
 #include "scpaths.h"
 #include "scribus.h"
-#include "util.h"
+#include "util_icon.h"
 
 int scribusshortwords_getPluginAPIVersion()
 {
@@ -73,7 +75,8 @@ void ShortWordsPlugin::languageChange()
 	m_actionInfo.text = tr("Short &Words...", "short words plugin");
 	// Menu
 	m_actionInfo.menu = "Extras";
-	m_actionInfo.enabledOnStartup = true;
+	m_actionInfo.enabledOnStartup = false;
+	m_actionInfo.needsNumObjects = -1;
 }
 
 const QString ShortWordsPlugin::fullTrName() const
@@ -107,38 +110,45 @@ void ShortWordsPlugin::deleteAboutData(const AboutData* about) const
 	delete about;
 }
 
-bool ShortWordsPlugin::run(QString target)
+bool ShortWordsPlugin::run(ScribusDoc* doc, QString target)
 {
+	if (doc==NULL)
+		return false;
 	Q_ASSERT(target.isEmpty());
 
-	uint originalPage = ScMW->doc->currentPage->pageNr();
-	SWDialog *dlg = new SWDialog(ScMW, "dlg", true, 0);
+	uint originalPage = doc->currentPage()->pageNr();
+	SWDialog *dlg = new SWDialog(doc->scMW());
 	if (dlg->exec() == QDialog::Accepted) {
 		SWParse *parse = new SWParse();
-		QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-		ScMW->mainWindowStatusLabel->setText(QObject::tr("Short Words processing. Wait please...", "short words plugin"));
-		switch (dlg->actionSelected) {
+		QApplication::changeOverrideCursor(QCursor(Qt::WaitCursor));
+		if (!dlg->useStyleLang())
+			parse->lang = dlg->lang();
+		else
+			parse->lang = ""; // get it from style
+
+		doc->scMW()->setStatusBarInfoText(QObject::tr("Short Words processing. Wait please...", "short words plugin"));
+		switch (dlg->actionSelected()) {
 			case 0:
-				parse->parseSelection();
+				parse->parseSelection(doc);
 				break;
 			case 1:
-				parse->parsePage(ScMW->doc->currentPage->pageNr());
+				parse->parsePage(doc, doc->currentPage()->pageNr());
 				break;
 			case 2:
-				parse->parseAll();
+				parse->parseAll(doc);
 				break;
 		} // switch
 		// enable "Save" icon
 		if (parse->modify > 0)
-			ScMW->slotDocCh(true);
+			doc->changed();
 		delete parse;
 		// redraw document
-		ScMW->view->DrawNew();
-		QApplication::restoreOverrideCursor();
-		ScMW->mainWindowStatusLabel->setText(QObject::tr("Short Words processing. Done.", "short words plugin"));
-		ScMW->mainWindowProgressBar->reset();
+		doc->view()->DrawNew();
+		QApplication::changeOverrideCursor(Qt::ArrowCursor);
+		doc->scMW()->setStatusBarInfoText(QObject::tr("Short Words processing. Done.", "short words plugin"));
+		doc->scMW()->mainWindowProgressBar->reset();
 		// set page where user calls vlna
-		ScMW->view->GotoPage(originalPage);
+		doc->view()->GotoPage(originalPage);
 	} // action
 	delete dlg;
 	return true;
