@@ -25,7 +25,9 @@ for which a new license (GPL+exception) is in place.
 	#include <windows.h>
 	#include <winspool.h>
 #else
+    #if defined (HAVE_CUPS)
 	#include <cups/cups.h>
+    #endif
 #endif
 #include "util_printer.h"
 #include "util_icon.h"
@@ -138,7 +140,10 @@ PrintDialog::PrintDialog( QWidget* parent, ScribusDoc* doc, const PrintOptions&
 	setStoredValues(printOptions.filename, gcr);
 #if defined(_WIN32)
 	if (!outputToFile())
+	{
+		DevMode = printOptions.devMode;
 		PrinterUtil::initDeviceSettings( PrintDest->currentText(), DevMode );
+	}
 #endif
 
 	printEngineMap = PrinterUtil::getPrintEngineSupport(PrintDest->currentText(), outputToFile());
@@ -313,7 +318,14 @@ void PrintDialog::SelPrinter(const QString& prn)
 		if (fi.isRelative()) // if (m_doc->DocName.startsWith( tr("Document")))
 			LineEdit1->setText( QDir::toNativeSeparators(QDir::currentPath() + "/" + m_doc->DocName + ".ps") );
 		else
-			LineEdit1->setText( QDir::toNativeSeparators(fi.path() + "/" + fi.baseName() + ".ps") );
+		{
+			QString completeBaseName = fi.completeBaseName();
+			if (completeBaseName.endsWith(".sla", Qt::CaseInsensitive))
+				if (completeBaseName.length() > 4) completeBaseName.chop(4);
+			if (completeBaseName.endsWith(".gz", Qt::CaseInsensitive))
+				if (completeBaseName.length() > 3) completeBaseName.chop(3);
+			LineEdit1->setText( QDir::toNativeSeparators(fi.path() + "/" + completeBaseName + ".ps") );
+		}
 	}
 
 	// Get page description language supported by the selected printer
