@@ -25,22 +25,24 @@ for which a new license (GPL+exception) is in place.
 #include <iostream>
 #include <cstdlib>
 
-#include <qstring.h>
-#include <qfont.h>
-#include <qtranslator.h>
-#include <qfileinfo.h>
-#include <qfile.h>
-#include <qdir.h>
-#include <qtextcodec.h>
+#include <QString>
+#include <QFont>
+#include <QTranslator>
+#include <QFileInfo>
+#include <QFile>
+#include <QDir>
+#include <QTextCodec>
+#include <QLocale>
+#include <QTextStream>
 
 #include "scribusapp.h"
-#include "scribusapp.moc"
-#include "scribus.h"
+#include "scribuscore.h"
 #include "scpaths.h"
 #include "prefsfile.h"
 #include "langmgr.h"
 #include "prefsmanager.h"
 #include "commonstrings.h"
+#include "upgradechecker.h"
 
 #if defined(_WIN32)
 #include <windows.h>
@@ -51,24 +53,28 @@ for which a new license (GPL+exception) is in place.
 #define ARG_LANG "--lang"
 #define ARG_AVAILLANG "--langs-available"
 #define ARG_NOSPLASH "--no-splash"
+#define ARG_NEVERSPLASH "--never-splash"
 #define ARG_NOGUI "--no-gui"
 #define ARG_DISPLAY "--display"
 #define ARG_FONTINFO "--font-info"
 #define ARG_PROFILEINFO "--profile-info"
 #define ARG_SWAPDIABUTTONS "--swap-buttons"
 #define ARG_PREFS "--prefs"
+#define ARG_UPGRADECHECK "--upgradecheck"
 
 #define ARG_VERSION_SHORT "-v"
 #define ARG_HELP_SHORT "-h"
 #define ARG_LANG_SHORT "-l"
 #define ARG_AVAILLANG_SHORT "-la"
 #define ARG_NOSPLASH_SHORT "-ns"
+#define ARG_NEVERSPLASH_SHORT "-nns"
 #define ARG_NOGUI_SHORT "-g"
 #define ARG_DISPLAY_SHORT "-d"
 #define ARG_FONTINFO_SHORT "-fi"
 #define ARG_PROFILEINFO_SHORT "-pi"
 #define ARG_SWAPDIABUTTONS_SHORT "-sb"
 #define ARG_PREFS_SHORT "-pr"
+#define ARG_UPGRADECHECK_SHORT "-u"
 
 // Qt wants -display not --display or -d
 #define ARG_DISPLAY_QT "-display"
@@ -78,19 +84,23 @@ extern const char ARG_CONSOLE[] =  "--console";
 extern const char ARG_CONSOLE_SHORT[] = "-cl";
 
 extern ScribusQApp* ScQApp;
+extern ScribusCore* ScCore;
 
 bool ScribusQApp::useGUI=false;
 
-ScribusQApp::ScribusQApp( int & argc, char ** argv ) : QApplication(argc, argv)
+ScribusQApp::ScribusQApp( int & argc, char ** argv ) : QApplication(argc, argv),
+	lang(""),
+	GUILang("")
 {
 	ScQApp=this;
-	ScMW=NULL;
-	lang="";
-	GUILang="";
+	ScCore=NULL;
+
+	initDLMgr();
 }
 
 ScribusQApp::~ScribusQApp()
 {
+	m_scDLMgr->deleteLater();
 	PrefsManager::deleteInstance();
 }
 
@@ -102,14 +112,21 @@ void ScribusQApp::initLang()
 		installTranslators(langs);
 }
 
+void ScribusQApp::initDLMgr()
+{
+	m_scDLMgr=new ScDLManager(this);
+	connect(m_scDLMgr, SIGNAL(fileReceived(const QString&)), SLOT(downloadComplete(const QString&)));
+}
+
 void ScribusQApp::parseCommandLine()
 {
-	showSplash=true;
-	QString arg = "";
+	showSplash=!neverSplashExists();
+	QString arg("");
 	bool usage=false;
 	bool header=false;
 	bool availlangs=false;
 	bool version=false;
+	bool runUpgradeCheck=false;
 	showFontInfo=false;
 	showProfileInfo=false;
 	swapDialogButtonOrder=false;
@@ -131,6 +148,9 @@ void ScribusQApp::parseCommandLine()
 		} else if (arg == ARG_AVAILLANG || arg == ARG_AVAILLANG_SHORT) {
 			header=true;
 			availlangs=true;
+		} else if (arg == ARG_UPGRADECHECK || arg == ARG_UPGRADECHECK_SHORT) {
+			header=true;
+			runUpgradeCheck=true;
 		}
 	}
 	//Init translations
@@ -144,6 +164,11 @@ void ScribusQApp::parseCommandLine()
 		showAvailLangs();
 	if (usage)
 		showUsage();
+	if (runUpgradeCheck)
+	{
+		UpgradeChecker uc;
+		uc.fetch();
+	}
 	//Dont run the GUI init process called from main.cpp, and return
 	if (!header)
 		useGUI=true;
@@ -159,6 +184,10 @@ void ScribusQApp::parseCommandLine()
 			continue;
 		} else if (arg == ARG_NOSPLASH || arg == ARG_NOSPLASH_SHORT) {
 			showSplash = false;
+		}
+		else if (arg == ARG_NEVERSPLASH || arg == ARG_NEVERSPLASH_SHORT) {
+			showSplash = false;
+			neverSplash(true);
 		} else if (arg == ARG_NOGUI || arg == ARG_NOGUI_SHORT) {
 			useGUI=false;
 		} else if (arg == ARG_FONTINFO || arg == ARG_FONTINFO_SHORT) {
@@ -175,10 +204,10 @@ void ScribusQApp::parseCommandLine()
 			prefsUserFile = QFile::decodeName(argv()[i + 1]);
 			if (!QFileInfo(prefsUserFile).exists()) {
 				showHeader();
-				if (file.left(1) == "-" || file.left(2) == "--") {
-					std::cout << tr("Invalid argument: ").local8Bit() << file << std::endl;
+				if (fileName.left(1) == "-" || fileName.left(2) == "--") {
+					std::cout << tr("Invalid argument: ").toLocal8Bit().data() << fileName.toLocal8Bit().data() << std::endl;
 				} else {
-					std::cout << tr("File %1 does not exist, aborting.").arg(file).local8Bit() << std::endl;
+					std::cout << tr("File %1 does not exist, aborting.").arg(fileName).toLocal8Bit().data() << std::endl;
 				}
 				showUsage();
 				useGUI=false;
@@ -186,61 +215,43 @@ void ScribusQApp::parseCommandLine()
 			} else {
 				++i;
 			}
-		} else if (strncmp(arg,"-psn_",4) == 0)
+		} else if (strncmp(arg.toLocal8Bit().data(),"-psn_",4) == 0)
 		{
 			// Andreas Vox: Qt/Mac has -psn_blah flags that must be accepted.
 		} else {
-			file = QFile::decodeName(argv()[i]);
-			if (!QFileInfo(file).exists()) {
+			fileName = QFile::decodeName(argv()[i]);
+			if (!QFileInfo(fileName).exists()) {
 				showHeader();
-				if (file.left(1) == "-" || file.left(2) == "--") {
-					std::cout << tr("Invalid argument: ").local8Bit() << file << std::endl;
+				if (fileName.left(1) == "-" || fileName.left(2) == "--") {
+					std::cout << tr("Invalid argument: %1").arg(fileName).toLocal8Bit().data() << std::endl;
 				} else {
-					std::cout << tr("File %1 does not exist, aborting.").arg(file).local8Bit() << std::endl;
+					std::cout << tr("File %1 does not exist, aborting.").arg(fileName).toLocal8Bit().data() << std::endl;
 				}
 				showUsage();
 				useGUI=false;
 				return;
 			}
+			else
+			{
+				filesToLoad.append(fileName);
+			}
 		}
 	}
 }
 
 int ScribusQApp::init()
 {
+	m_ScCore=new ScribusCore();
+	Q_CHECK_PTR(m_ScCore);
+	if (!m_ScCore)
+		return EXIT_FAILURE;
+	ScCore=m_ScCore;
 	processEvents();
+	ScCore->init(useGUI, swapDialogButtonOrder, filesToLoad);
+	int retVal=EXIT_SUCCESS;
 	if (useGUI)
-	{
-		scribus = new ScribusMainWindow();
-		ScMW=scribus;
-		if (!scribus)
-			exit(EXIT_FAILURE);
-		int scribusRetVal = scribus->initScribus(showSplash, showFontInfo, showProfileInfo, lang, prefsUserFile);
-		if (scribusRetVal == 1)
-			return(EXIT_FAILURE);
-
-		setMainWidget(scribus);
-		connect(this, SIGNAL(lastWindowClosed()), this, SLOT(quit()));
-
-		scribus->show();
-		scribus->ShowSubs();
-
-		if (!file.isEmpty())
-			scribus->loadDoc(file);
-		else
-		{
-			if (PrefsManager::instance()->appPrefs.showStartupDialog)
-				scribus->startUpDialog();
-			else
-				scribus->setFocus();
-		}
-
-		// A hook for plug-ins and scripts to trigger on. Some plugins and scripts
-		// require the app to be fully set up (in particular, the main window to be
-		// built and shown) before running their setup.
-		emit appStarted();
-	}
-	return EXIT_SUCCESS;
+		retVal=ScCore->startGUI(showSplash, showFontInfo, showProfileInfo, lang, prefsUserFile);
+	return retVal;
 }
 
 QStringList ScribusQApp::getLang(QString lang)
@@ -252,7 +263,7 @@ QStringList ScribusQApp::getLang(QString lang)
 		langs.push_back(lang);
 
 	//add in user preferences lang, only overridden by lang command line option
-	QString Pff = QDir::convertSeparators(QDir::homeDirPath()+"/.scribus");
+	QString Pff = QDir::toNativeSeparators(ScPaths::getApplicationDataDir());
 	QFileInfo Pffi = QFileInfo(Pff);
 	if (Pffi.exists())
 	{
@@ -260,8 +271,8 @@ QStringList ScribusQApp::getLang(QString lang)
 		if (Pffi.isDir())
 			PrefsPfad = Pff;
 		else
-			PrefsPfad = QDir::homeDirPath();
-		QString prefsXMLFile=QDir::convertSeparators(PrefsPfad + "/prefs13.xml");
+			PrefsPfad = QDir::homePath();
+		QString prefsXMLFile=QDir::toNativeSeparators(PrefsPfad + "/prefs140.xml");
 		QFileInfo infoPrefsFile(prefsXMLFile);
 		if (infoPrefsFile.exists())
 		{
@@ -274,6 +285,7 @@ QStringList ScribusQApp::getLang(QString lang)
 						langs.push_back(prefslang);
 				}
 			}
+			delete prefsFile;
 		}
 	}
 
@@ -293,24 +305,28 @@ QStringList ScribusQApp::getLang(QString lang)
 	LCID lcIdn = MAKELCID(langId, sortId);
 	if ( GetLocaleInfoW(lcIdn, LOCALE_SISO639LANGNAME , out, 255) )
 	{
-		language = QString::fromUcs2( (ushort*)out );
+		language = QString::fromUtf16( (ushort*)out );
 		if ( GetLocaleInfoW(lcIdn, LOCALE_SISO3166CTRYNAME, out, 255) )
 		{
-			sublanguage = QString::fromUcs2( (ushort*)out ).lower();
+			sublanguage = QString::fromUtf16( (ushort*)out ).toLower();
 			lang = language;
 			if ( sublanguage != language && !sublanguage.isEmpty() )
-				lang += "_" + sublanguage.upper();
+				lang += "_" + sublanguage.toUpper();
 			langs.push_back(lang);
 		}
 	}
 #endif
 
-	langs.push_back(QString(QTextCodec::locale()));
+	langs.push_back(QString(QLocale::system().name()));
 
 	// remove duplicate entries...
-	for (QStringList::Iterator it = langs.fromLast(); it != langs.begin(); --it)
-		if (langs.contains(*it) > 1)
-			it = langs.remove(it);
+	QStringList::Iterator it = langs.end();
+	while (it != langs.begin())
+	{
+		--it;
+		if (langs.count(*it) > 1)
+			it = langs.erase(it);
+	}
 
 	return langs;
 }
@@ -330,14 +346,17 @@ void ScribusQApp::installTranslators(const QStringList & langs)
 
 	bool loaded = false;
 	QString lang;
-	for (QStringList::const_iterator it = langs.constBegin(); it != langs.constEnd() && !loaded; ++it) {
-		lang=(*it).left(5);
+	for (QStringList::const_iterator it = langs.constBegin(); it != langs.constEnd() && !loaded; ++it) 
+	{
+		lang=(*it);
 		if (lang == "en")
+		{
+			GUILang=lang;
 			break;
-		else if (loaded = trans->load(QString(path + '.' + lang), "."))
+		}
+		else if (trans->load(QString(path + '.' + lang), "."))
 			loaded = true;
 	}
-
 	if (loaded)
 	{
 		installTranslator(trans);
@@ -351,8 +370,8 @@ void ScribusQApp::installTranslators(const QStringList & langs)
 	if (dir.exists() && (dir.count() != 0)) {
 		for (uint i = 0; i < dir.count(); ++i) {
 			QFileInfo file(path + dir[i]);
-			if ((file.extension(false).lower() == "qm")
-			&& (file.extension(true).lower().left(5) == lang)) {
+			if ((file.extension(false).toLower() == "qm")
+			&& (file.extension(true).toLower().left(5) == lang)) {
 				trans = new QTranslator(0);
 				trans->load(QString(path + dir[i]), ".");
 				installTranslator(trans);
@@ -381,7 +400,7 @@ static void printArgLine(QTextStream & ts, const char * smallArg,
 						  const char* fullArg, const QString desc)
 {
 	const char* lineformat = "  %1, %2 %3";
-	const int saw = 3;   // Short argument width
+	const int saw = 4;   // Short argument width
 	const int aw = -18;   // Argument width (negative is left aligned)
 	QString line = QString(lineformat)
 		.arg(smallArg, saw)
@@ -394,31 +413,25 @@ static void printArgLine(QTextStream & ts, const char * smallArg,
 void ScribusQApp::showUsage()
 {
 	QFile f;
-	f.open(IO_WriteOnly, stderr);
+	f.open(stderr, QIODevice::WriteOnly);
 	QTextStream ts(&f);
 	ts << tr("Usage: scribus [option ... ] [file]") ; endl(ts);
 	ts << tr("Options:") ; endl(ts);
-	printArgLine(ts, ARG_HELP_SHORT, ARG_HELP,
-		tr("Print help (this message) and exit") );
-	printArgLine(ts, ARG_LANG_SHORT, ARG_LANG,
-		tr("Uses xx as shortcut for a language, eg `en' or `de'") );
-	printArgLine(ts, ARG_AVAILLANG_SHORT, ARG_AVAILLANG,
-		tr("List the currently installed interface languages") );
-	printArgLine(ts, ARG_FONTINFO_SHORT, ARG_FONTINFO,
-		tr("Show information on the console when fonts are being loaded") );
-	printArgLine(ts, ARG_NOSPLASH_SHORT, ARG_NOSPLASH,
-		tr("Do not show the splashscreen on startup") );
-	printArgLine(ts, ARG_VERSION_SHORT, ARG_VERSION,
-		tr("Output version information and exit") );
-	printArgLine(ts, ARG_SWAPDIABUTTONS_SHORT, ARG_SWAPDIABUTTONS,
-		tr("Use right to left dialog button ordering (eg. Cancel/No/Yes instead of Yes/No/Cancel)") );
-	printArgLine(ts, ARG_PREFS_SHORT, QString(ARG_PREFS)+" " + tr("filename"),
-		tr("Use filename as path for user given preferences") );
-	printArgLine(ts, ARG_PROFILEINFO_SHORT, ARG_PROFILEINFO, 
-		tr("Show location ICC profile information on console while starting") );
+	printArgLine(ts, ARG_FONTINFO_SHORT, ARG_FONTINFO, tr("Show information on the console when fonts are being loaded") );
+	printArgLine(ts, ARG_HELP_SHORT, ARG_HELP, tr("Print help (this message) and exit") );
+	printArgLine(ts, ARG_LANG_SHORT, ARG_LANG, tr("Uses xx as shortcut for a language, eg `en' or `de'") );
+	printArgLine(ts, ARG_AVAILLANG_SHORT, ARG_AVAILLANG, tr("List the currently installed interface languages") );
+	printArgLine(ts, ARG_NOSPLASH_SHORT, ARG_NOSPLASH, tr("Do not show the splashscreen on startup") );
+	printArgLine(ts, ARG_NEVERSPLASH_SHORT, ARG_NEVERSPLASH, tr("Stop the showing of the splashscreen on startup. Writes an empty file called .neversplash in ~/.scribus.") );
+	printArgLine(ts, ARG_PREFS_SHORT, QString(QString(ARG_PREFS) + QString(" ") + tr("filename")).toLocal8Bit().constData(), tr("Use filename as path for user given preferences") );
+	printArgLine(ts, ARG_PROFILEINFO_SHORT, ARG_PROFILEINFO, tr("Show location ICC profile information on console while starting") );
+	printArgLine(ts, ARG_SWAPDIABUTTONS_SHORT, ARG_SWAPDIABUTTONS, tr("Use right to left dialog button ordering (eg. Cancel/No/Yes instead of Yes/No/Cancel)") );
+	printArgLine(ts, ARG_UPGRADECHECK_SHORT, ARG_UPGRADECHECK, tr("Download a file from the Scribus website and show the latest available version.") );
+	printArgLine(ts, ARG_VERSION_SHORT, ARG_VERSION, tr("Output version information and exit") );
+	
+	
 #if defined(_WIN32) && !defined(_CONSOLE)
-	printArgLine(ts, ARG_CONSOLE_SHORT, ARG_CONSOLE,
-		tr("Display a console window") );
+	printArgLine(ts, ARG_CONSOLE_SHORT, ARG_CONSOLE, tr("Display a console window") );
 #endif
 /* Delete me?
 	std::cout << "-file|-- name Open file 'name'" ; endl(ts);
@@ -431,14 +444,14 @@ void ScribusQApp::showUsage()
 void ScribusQApp::showAvailLangs()
 {
 	QFile f;
-	f.open(IO_WriteOnly, stderr);
+	f.open(stderr, QIODevice::WriteOnly);
 	QTextStream ts(&f);
 	ts << tr("Installed interface languages for Scribus are as follows:"); endl(ts);
 	endl(ts);
 
-	LanguageManager langMgr;
-	langMgr.init();
-	langMgr.printInstalledList();
+// 	LanguageManager langMgr;
+// 	langMgr.init();
+	LanguageManager::instance()->printInstalledList();
 
 	endl(ts);
 	ts << tr("To override the default language choice:"); endl(ts);
@@ -447,18 +460,18 @@ void ScribusQApp::showAvailLangs()
 
 void ScribusQApp::showVersion()
 {
-	std::cout << tr("Scribus Version").local8Bit() << " " << VERSION << std::endl;
+	std::cout << tr("Scribus Version").toLocal8Bit().data() << " " << VERSION << std::endl;
 }
 
 void ScribusQApp::showHeader()
 {
 	QFile f;
-	f.open(IO_WriteOnly, stderr);
+	f.open(stderr, QIODevice::WriteOnly);
 	QTextStream ts(&f);
 	endl(ts);
 	QString heading( tr("Scribus, Open Source Desktop Publishing") );
 	// Build a separator of ----s the same width as the heading
-	QString separator = QString("").rightJustify(heading.length(),'-');
+	QString separator = QString("").rightJustified(heading.length(),'-');
 	// Then output the heading, separator, and docs/www/etc info in an aligned table
 	const int urlwidth = 23;
 	const int descwidth = -(heading.length() - urlwidth - 1);
@@ -471,53 +484,57 @@ void ScribusQApp::showHeader()
 	endl(ts);
 }
 
-bool ScribusQApp::usingGUI() const
+void ScribusQApp::neverSplash(bool splashOff)
 {
-	return useGUI;
+	QString prefsDir = ScPaths::getApplicationDataDir();
+	QFile ns(prefsDir + ".neversplash");
+	if (splashOff)
+	{
+		if (QFileInfo(QDir::homePath()).exists())
+		{
+			QDir prefsDirectory(prefsDir);
+			if (!QFileInfo(prefsDir).exists())
+				prefsDirectory.mkdir(prefsDir);
+			if (!ns.exists() && ns.open(QIODevice::WriteOnly))
+				ns.close();
+		}
+	}
+	else
+	{
+		if (neverSplashExists())
+			ns.remove();
+	}
 }
 
-bool ScribusQApp::isMacGUI() const
+bool ScribusQApp::neverSplashExists()
 {
-	// Do it statically for now
-#if defined(Q_WS_MAC)
-	return true;
-#else
-	return false;
-#endif
+	return QFileInfo(ScPaths::getApplicationDataDir() + ".neversplash").exists();
 }
 
-bool ScribusQApp::isWinGUI() const
+void ScribusQApp::downloadComplete(const QString &t)
 {
-	// Do it statically for now
-#if defined(_WIN32)
-	return true;
-#else
-	return false;
-#endif
+	qDebug()<<"ScribusQApp: download finished:"<<t;
 }
 
-bool ScribusQApp::reverseDialogButtons() const
+bool ScribusQApp::event(QEvent *event)
 {
-	if (swapDialogButtonOrder)
-		return true;
-	//Win32 - dont switch
-	#if defined(_WIN32)
-		return false;
-	//Mac Aqua - switch
-	#elif defined(Q_WS_MAC)
-		return true;
-	#else
-	//Gnome - switch
-	QString gnomesession= ::getenv("GNOME_DESKTOP_SESSION_ID");
-	if (!gnomesession.isEmpty())
-		return true;
-
-	//KDE/KDE Aqua - dont switch
-	//Best guess for now if we are running under KDE
-	QString kdesession= ::getenv("KDE_FULL_SESSION");
-	if (!kdesession.isEmpty())
-		return false;
-	#endif
-	return false;
+	switch (event->type()) 
+	{
+	case QEvent::FileOpen:
+		{
+			QString filename = static_cast<QFileOpenEvent*>(event)->file();
+			if(m_ScCore && m_ScCore->initialized())
+			{
+				ScribusMainWindow* mw = m_ScCore->primaryMainWindow();
+				mw->loadDoc(filename);
+			}
+			else
+			{
+				filesToLoad.append(filename);
+			}
+			return true;
+		}
+	default:
+		return QApplication::event(event);
+	}
 }
-
