@@ -11,23 +11,47 @@ for which a new license (GPL+exception) is in place.
 #include "scconfig.h"
 #endif
 
-#include <qvaluestack.h>
-#include <qvaluelist.h>
-#include <qvaluevector.h>
-#include <qstring.h>
-#include <qaction.h>
-#include <qkeysequence.h>
+#include <QAction>
+#include <QByteArray>
+#include <QDebug>
+#include <QKeySequence>
+#include <QList>
+#include <QPolygon>
+#include <QStack>
+#include <QString>
+#include <QMap>
+#include <QVector>
+
 #include <vector>
 
+#include "scribusapi.h"
+#include "colormgmt/sccolormgmtstructs.h"
+#include "scimagestructs.h"
 #include "sctextstruct.h"
 #include "scfonts.h"
-#include "scimage.h"
 #include "fpointarray.h"
 #include "vgradient.h"
 #include "annotation.h"
 #include "pageitem.h"
 
-extern bool compareDouble(double, double);
+extern bool SCRIBUS_API compareDouble(double, double);
+
+typedef struct
+{
+	int r;
+	int g;
+	int b;
+	void getValues(int& vr, int& vg, int& vb) {vr = r; vg = g; vb = b;}
+} RGBColor;
+
+typedef struct
+{
+	int c;
+	int m;
+	int y;
+	int k;
+	void getValues(int& vc, int& vm, int& vy, int& vk) {vc = c; vm = m; vy = y; vk = k;}
+} CMYKColor;
 
 struct CopyPasteBuffer
 {
@@ -42,8 +66,8 @@ struct CopyPasteBuffer
 	double Pwidth;
 	QString Pcolor;
 	QString Pcolor2;
-	int Shade;
-	int Shade2;
+	double Shade;
+	double Shade2;
 	int FillRule;
 	QString GrColor;
 	QString GrColor2;
@@ -51,6 +75,12 @@ struct CopyPasteBuffer
 	int GrShade2;
 	VGradient fill_gradient;
 	int GrType;
+	QString pattern;
+	double patternScaleX;
+	double patternScaleY;
+	double patternOffsetX;
+	double patternOffsetY;
+	double patternRotation;
 	double GrStartX;
 	double GrStartY;
 	double GrEndX;
@@ -93,26 +123,27 @@ struct CopyPasteBuffer
 	double TExtra;
 	double BExtra;
 	double RExtra;
+	FirstLineOffsetPolicy firstLineOffsetP;
 	QString Pfile;
 	QString Pfile2;
 	QString Pfile3;
 	QString IProfile;
 	QString EmProfile;
-	int IRender;
+	eRenderIntent IRender;
 	bool UseEmbedded;
 	QString itemText;
-	QPointArray Clip;
+	QPolygon Clip;
 	FPointArray PoLine;
 	FPointArray ContourLine;
 	bool PoShow;
 	double BaseOffs;
-	bool Textflow;
-	bool Textflow2;
-	bool UseContour;
+	int textPathType;
+	bool textPathFlipped;
+	int TextflowMode;
 	int textAlignment;
 	QString IFont;
 	int ISize;
-	QValueStack<int> Groups;
+	QStack<int> Groups;
 	int LayerNr;
 	bool ScaleType;
 	bool AspectRatio;
@@ -120,14 +151,16 @@ struct CopyPasteBuffer
 	bool LockRes;
 	double Transparency;
 	double TranspStroke;
+	int TransBlend;
+	int TransBlendS;
 	bool Reverse;
 	QString NamedLStyle;
 	QString Language;
 	QString guiLanguage;
 	int Cols;
 	double ColGap;
-	QValueList<PageItem::TabRecord> TabValues;
-	QValueList<double> DashValues;
+	QList<ParagraphStyle::TabRecord> TabValues;
+	QVector<double> DashValues;
 	double DashOffset;
 	bool isTableItem;
 	bool TopLine;
@@ -153,22 +186,43 @@ struct CopyContentsBuffer
 	double LocalY;
 	double ItemX;
 	double ItemY;
+	ScImageEffectList effects;
 	QString inputProfile;
 	bool   useEmbedded;
-	int    renderingIntent;
-	QValueList<ScImage::imageEffect> effects;
+	eRenderIntent renderingIntent;
 };
 
-/** Pagemargins */
-struct MarginStruct
+/** \brief Pagemargins and bleeds*/
+class MarginStruct
 {
-	MarginStruct() : Top(0), Left(0), Bottom(0), Right(0) {}
-	MarginStruct(double top, double left, double bottom, double right) :
-		Top(top), Left(left), Bottom(bottom), Right(right) {}
-	double Top;
-	double Left;
-	double Bottom;
-	double Right;
+	public:
+		MarginStruct() : Top(0), Left(0), Bottom(0), Right(0) {}
+		MarginStruct(double top, double left, double bottom, double right) :
+			Top(top), Left(left), Bottom(bottom), Right(right) {}
+		MarginStruct(const MarginStruct& rhs) {Top=rhs.Top;Bottom=rhs.Bottom;Left=rhs.Left;Right=rhs.Right;}
+		void set(double top, double left, double bottom, double right) {Top=top;Bottom=bottom;Left=left;Right=right;}
+		void resetToZero() {Top=0.0;Bottom=0.0;Left=0.0;Right=0.0;}
+		bool hasNonZeroValue() { return Top!=0.0 || Bottom!=0.0 || Left!=0.0 || Right!=0.0;}
+		void print() {qDebug() << Top << Left << Bottom << Right;}
+		double Top;
+		double Left;
+		double Bottom;
+		double Right;
+};
+
+struct DocPagesSetup
+{
+	DocPagesSetup() : pageArrangement(0), firstPageLocation(0), firstPageNumber(0), orientation(0), autoTextFrames(false), columnDistance(0), columnCount(1) {}
+	DocPagesSetup(int pa, int fpl, int fpn, int o, bool atf, double cd, double cc) :
+		pageArrangement(pa), firstPageLocation(fpl), firstPageNumber(fpn), orientation(o), autoTextFrames(atf),
+		columnDistance(cd), columnCount(cc) {}
+	int pageArrangement;
+	int firstPageLocation;
+	int firstPageNumber;
+	int orientation;
+	bool autoTextFrames;
+	double columnDistance;
+	double columnCount;
 };
 
 struct PageSet
@@ -177,61 +231,28 @@ struct PageSet
 	int FirstPage;
 	int Rows;
 	int Columns;
-	double GapHorizontal;
-	double GapVertical;
-	double GapBelow;
+//	double GapHorizontal;
+//	double GapVertical;
+//	double GapBelow;
 	QStringList pageNames;
 };
 
-struct ParagraphStyle
-{
-	QString Vname;
-	int LineSpaMode;      // 0 = fixed; 1 = Automatic; 2 = Adjust to Baseline Grid
-	double LineSpa;
-	int textAlignment;
-	double Indent;
-	double First;
-	double gapBefore;
-	double gapAfter;
-	QString Font;
-	int FontSize;
-	QValueList<PageItem::TabRecord> TabValues;
-	bool Drop;
-	int DropLin;
-	double DropDist;
-	int FontEffect;
-	QString FColor;
-	int FShade;
-	QString SColor;
-	int SShade;
-	bool BaseAdj;
-	int txtShadowX;
-	int txtShadowY;
-	int txtOutline;
-	int txtUnderPos;
-	int txtUnderWidth;
-	int txtStrikePos;
-	int txtStrikeWidth;
-	int scaleH;
-	int scaleV;
-	int baseOff;
-	int kernVal;
-};
-
 struct CMSData
 {
 	QString DefaultMonitorProfile;
 	QString DefaultPrinterProfile;
 	QString DefaultImageRGBProfile;
 	QString DefaultImageCMYKProfile;
-	QString DefaultSolidColorProfile;
+	QString DefaultSolidColorRGBProfile;
+	QString DefaultSolidColorCMYKProfile;
 	int ComponentsInput2;
+	int ComponentsInput3;
 	int ComponentsPrinter;
-	int DefaultIntentMonitor;
-	int DefaultIntentImages;
-	int DefaultIntentPrinter;
+	eRenderIntent DefaultIntentImages;
+	eRenderIntent DefaultIntentColors;
 	bool CMSinUse;
 	bool SoftProofOn;
+	bool SoftProofFullOn;
 	bool GamutCheck;
 	bool BlackPoint;
 } ;
@@ -244,6 +265,13 @@ struct SingleLine
 	int LineJoin;
 	QString Color;
 	int Shade;
+	// setter necessary for use with serializer/digester
+	void setLineWidth(double value) { Width = value; }
+	void setDash(int value)         { Dash = value; }
+	void setLineEnd(int value)      { LineEnd = value; }
+	void setLineJoin(int value)     { LineJoin = value; }
+	void setColor(const QString& name) { Color = name; }
+	void setShade(int value)        { Shade = value; }
 	bool operator==(const SingleLine& other) const
 	{
 		if (!compareDouble(Width, other.Width) )
@@ -266,16 +294,6 @@ struct ArrowDesc
 	FPointArray points;
 };
 
-struct Layer
-{
-	int LNr;
-	int Level;
-	QString Name;
-	bool isPrintable;
-	bool isViewable;
-	bool isEditable;
-};
-
 struct PDFPresentationData
 {
 	int pageEffectDuration;
@@ -299,19 +317,25 @@ struct Keys
 	QString cleanMenuText;
 	QKeySequence keySequence;
 	int tableRow;
+	QString menuName;
+	int menuPos;
 };
 
+enum PrintEngine
+{
+	PostScript1 = 1,
+	PostScript2 = 2,
+	PostScript3 = 3,
+	WindowsGDI  = 4
+};
+typedef QMap<QString, PrintEngine> PrintEngineMap;
+
 struct PrintOptions
 {
-	QString printer;
-	QString filename;
+	bool firstUse;
 	bool toFile;
 	bool useAltPrintCommand;
-	QString printerCommand;
-	int PSLevel;
 	bool outputSeparations;
-	QString separationName;
-	QStringList allSeparations;
 	bool useSpotColors;
 	bool useColor;
 	bool mirrorH;
@@ -320,23 +344,39 @@ struct PrintOptions
 	bool doGCR;
 	bool doClip;
 	bool setDevParam;
-	int copies;
+	bool useDocBleeds;
+	bool cropMarks;
+	bool bleedMarks;
+	bool registrationMarks;
+	bool colorMarks;
+	bool includePDFMarks;
+	int  copies;
+	PrintEngine prnEngine;
+	double markOffset;
+	MarginStruct bleeds;
 	std::vector<int> pageNumbers;
 	QString printerOptions;
+	QString printer;
+	QString filename;
+	QString separationName;
+	QStringList allSeparations;
+	QString printerCommand;
+	QByteArray devMode; // printer specific options on Windows
 };
 
 typedef QMap<QString,QString> ProfilesL;
+// typedef QValueVector<SingleLine> multiLine;
 
-class multiLine : public QValueVector<SingleLine>
-{
+class multiLine : public QList<SingleLine> {
 public:
+	QString shortcut;
 	bool operator!=(const multiLine& other) const
 	{
 		return !(this->operator ==(other));
 	}
 };
 
-
+//CB: Using 17 for OffConflictLayers as we moved onto 17 in 150svn
 typedef enum {
 	MissingGlyph=1,
 	TextOverflow=2,
@@ -346,7 +386,11 @@ typedef enum {
 	Transparency=6,
 	PDFAnnotField=7,
 	PlacedPDF=8,
-	WrongFontInAnnotation=9
+	ImageDPITooHigh=9,
+	ImageIsGIF=10,
+	BlendMode=11,
+	WrongFontInAnnotation=12,
+	OffConflictLayers=17
 } PreflightError;
 
 typedef QMap<PreflightError, int> errorCodes;
@@ -356,7 +400,7 @@ enum AppMode
 	modeNormal,
 	modeDrawShapes,
 	modeStoryEditor,
-	modeDrawPicture,
+	modeDrawImage,
 	modeDrawText,
 	modeMagnifier,
 	modeEdit,
@@ -379,7 +423,10 @@ enum AppMode
 	modeMeasurementTool,
 	modeEditGradientVectors,
 	modeEyeDropper,
-	modeCopyProperties
+	modeCopyProperties,
+	modeEditClip,
+	modeDrawLatex,
+	modeImportObject
 };
 
 struct AlignObjs
@@ -392,10 +439,10 @@ struct AlignObjs
 	double y2;
 	double width;
 	double height;
-	QPtrList<PageItem> Objects;
+	QList<PageItem*> Objects;
 };
 
-/*! Human readable orientations */
+/*! \brief Human readable orientations */
 enum PageOrientation
 {
 	portraitPage = 0,
@@ -403,4 +450,28 @@ enum PageOrientation
 	customPage = 30
 };
 
+//! \brief Common type for guides list
+typedef QList<double> Guides;
+
+//! \brief from ols scribusXml
+struct Linked 
+{ 
+	int Start;
+	int StPag;
+};
+
+// this is a quick hack to combine runs until I've thought of something better -- AV
+class LastStyles {
+public:
+	CharStyle Style;
+	int StyleStart;
+	QString ParaStyle;
+	LastStyles() {
+		StyleStart = 0;
+		ParaStyle = "";
+	}
+};
+
 #endif
+
+
