@@ -1,19 +1,13 @@
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+For general Scribus (>=1.3.2) copyright and licensing information please refer
+to the COPYING file provided with the program. Following this notice may exist
+a copyright and/or license notice that predates the release of Scribus 1.3.2
+for which a new license (GPL+exception) is in place.
+*/
 #ifndef SEARCHREPLACE_H
 #define SEARCHREPLACE_H
 
-#include <qvariant.h>
-#include <qdialog.h>
-#include "scribusdoc.h"
-#include "pageitem.h"
-
+#include <QDialog>
 class QVBoxLayout;
 class QHBoxLayout;
 class QGridLayout;
@@ -22,19 +16,24 @@ class QComboBox;
 class QGroupBox;
 class QLineEdit;
 class QPushButton;
-class MSpinBox;
+class QLabel;
+
+#include "scribusapi.h"
+class ScrSpinBox;
 class FontCombo;
 class StyleSelect;
 class ShadeButton;
-class QLabel;
 class PrefsContext;
+class ColorCombo;
+class ScribusDoc;
+class PageItem;
 
-class SearchReplace : public QDialog
+class SCRIBUS_API SearchReplace : public QDialog
 {
 	Q_OBJECT
 
 public:
-	SearchReplace( QWidget* parent, ScribusDoc *doc, preV *Prefs, PageItem* ite, bool mode = true );
+	SearchReplace( QWidget* parent, ScribusDoc *doc, PageItem* ite, bool mode = true );
 	~SearchReplace() {};
 	virtual void slotDoSearch();
 	virtual void slotDoReplace();
@@ -49,16 +48,18 @@ public:
 	QCheckBox* SSize;
 	QCheckBox* SFont;
 	QCheckBox* SStyle;
+	QCheckBox* SAlign;
 	QCheckBox* SText;
 	QCheckBox* SEffect;
 	QCheckBox* REffect;
 	QLineEdit* STextVal;
 	QComboBox* SStyleVal;
+	QComboBox* SAlignVal;
 	FontCombo* SFontVal;
-	MSpinBox* SSizeVal;
-	QComboBox* SFillVal;
+	ScrSpinBox* SSizeVal;
+	ColorCombo* SFillVal;
 	ShadeButton *SFillSVal;
-	QComboBox* SStrokeVal;
+	ColorCombo* SStrokeVal;
 	ShadeButton *SStrokeSVal;
 	QGroupBox* Replace;
 	QCheckBox* RStroke;
@@ -68,14 +69,16 @@ public:
 	QCheckBox* RSize;
 	QCheckBox* RFont;
 	QCheckBox* RStyle;
+	QCheckBox* RAlign;
 	QCheckBox* RText;
 	QLineEdit* RTextVal;
 	QComboBox* RStyleVal;
+	QComboBox* RAlignVal;
 	FontCombo* RFontVal;
-	MSpinBox* RSizeVal;
-	QComboBox* RFillVal;
+	ScrSpinBox* RSizeVal;
+	ColorCombo* RFillVal;
 	ShadeButton *RFillSVal;
-	QComboBox* RStrokeVal;
+	ColorCombo* RStrokeVal;
 	ShadeButton *RStrokeSVal;
 	StyleSelect* SEffVal;
 	StyleSelect* REffVal;
@@ -99,6 +102,7 @@ public slots:
 	virtual void slotReplaceAll();
 	virtual void enableTxSearch();
 	virtual void enableStyleSearch();
+	virtual void enableAlignSearch();
 	virtual void enableFontSearch();
 	virtual void enableSizeSearch();
 	virtual void enableEffSearch();
@@ -108,6 +112,7 @@ public slots:
 	virtual void enableStrokeSSearch();
 	virtual void enableTxReplace();
 	virtual void enableStyleReplace();
+	virtual void enableAlignReplace();
 	virtual void enableFontReplace();
 	virtual void enableSizeReplace();
 	virtual void enableEffReplace();
@@ -119,7 +124,7 @@ public slots:
 	virtual void clear();
 
 signals:
-	void NewFont(QString);
+	void NewFont(const QString&);
 	void NewAbs(int);
 
 protected:
@@ -131,6 +136,9 @@ protected:
 	QHBoxLayout* ButtonsLayout;
 	virtual void readPrefs();
 
+	/// Number of matches found thus far in a search
+	int matchesFound;
+
 };
 
 #endif // SEARCHREPLACE_H
