@@ -21,7 +21,7 @@ for which a new license (GPL+exception) is in place.
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
  ***************************************************************************/
 
 #ifndef UNDOMANAGER_H
@@ -601,6 +601,7 @@ public:
 	static QString LinkTextFrame;
 	static QString UnlinkTextFrame;
 	static QString MovePage;
+	static QString PathOperation;
 	/*@}*/
 
 	/**
